import { Compilation, Parser, Expression } from "webpack";
import { SourceMapConsumer } from 'source-map';
export interface Value {
    key: string;
    line: number;
    column: number;
}
export interface Literal {
    type: "literal";
    value: Value;
}
export interface Identifier {
    type: "identifier";
    name: string;
}
export interface Or {
    type: "or";
    value: Arg[];
}
export interface And {
    type: "and";
    value: Arg[];
}
export interface Empty {
    type: "empty";
}
export declare type Arg = Literal | Identifier | Or | And | Empty;
export interface Option {
    defaultLanguage: string;
    /**
     * languages to emit
     */
    languages: string[];
    defaultNamespace?: string;
    namespaceSeparator?: string;
    namespaces?: string[];
    /**
     * Scanning function name
     *
     * @default "__"
     */
    functionName?: string;
    resourcePath: string;
    /**
     * save missing translations to...
     */
    pathToSaveMissing: string;
    /**
     * change emit path
     * if this value is not set, emit to resourcePath
     */
    outPath?: string;
}
export interface InternalOption extends Option {
    defaultNamespace: string;
    namespaces: string[];
    outPath: string;
}
export declare type CollectedKeys = {
    [language: string]: {
        [namespace: string]: {
            [key: string]: {
                [module: string]: [number, number];
            };
        };
    };
};
export default class I18nextPlugin {
    protected compilation: Compilation;
    protected option: InternalOption;
    protected context: string;
    protected missingKeys: CollectedKeys;
    protected startTime: number;
    protected prevTimestamps: {
        [file: string]: number;
    };
    protected sourceMaps: {
        [key: string]: SourceMapConsumer;
    };
    protected missingDirInitialized: boolean;
    constructor(option: Option);
    apply(compiler: any): void;
    protected initMissingDir(): Promise<void>;
    protected onEmit(compilation: Compilation, callback: (err?: Error) => void): Promise<void>;
    protected readonly outPath: string;
    protected onAfterEmit(compilation: Compilation, callback: (err?: Error) => void): Promise<void>;
    protected argsToSource(sourceMap: SourceMapConsumer, arg: Expression): Promise<string | null>;
    protected static onTranslateFunctionCall(this: Parser, plugin: I18nextPlugin, expr: Expression): Promise<void>;
    protected separateNamespace(key: string): string[];
    protected testArg(arg: Arg, lng: string): Value[];
    protected addToMissingKey(lng: string, ns: string, key: string, pos: [string, number, number]): void;
    protected onKeyMissing(): boolean;
    protected warningOnCompilation(msg: string): void;
}
